@@ -1,6 +1,6 @@
 #[test]
 fn test() {
-	let s = b"
+	let t: Vec<Option<String>> = crate::from_bytes(b"
 		foo
 		none # comment
 		None
@@ -11,10 +11,7 @@ fn test() {
 			none
 		: # comment
 			none
-	";
-
-	let mut d = crate::Deserializer::from(buffered_reader::Memory::new(s));
-	let t = <Vec<Option<String>> as serde::de::Deserialize>::deserialize(&mut d).unwrap();
+	").unwrap();
 	assert_eq!(t, [
 		Some("foo".into()),
 		None,
@@ -28,7 +25,7 @@ fn test() {
 
 #[test]
 fn dict() {
-	let s = b"
+	let t: std::collections::BTreeMap<String,Option<String>> = crate::from_bytes(b"
 		dog:
 			none # comment
 		fish: # comment
@@ -42,10 +39,7 @@ fn dict() {
 			none
 		minx: # comment
 			none
-	";
-
-	let mut d = crate::Deserializer::from(buffered_reader::Memory::new(s));
-	let t = <std::collections::BTreeMap<String,Option<String>> as serde::de::Deserialize>::deserialize(&mut d).unwrap();
+	").unwrap();
 	assert_eq!(t, std::array::IntoIter::new([
 		("dog".into(), None),
 		("fish".into(), Some("".into())),
